==> servicecatalog-model-5.10.2-sources.jar: io/fabric8/servicecatalog/api/model/ClusterServiceClassSpecBuilder.java <==
package io.fabric8.servicecatalog.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ClusterServiceClassSpecBuilder extends io.fabric8.servicecatalog.api.model.ClusterServiceClassSpecFluentImpl<io.fabric8.servicecatalog.api.model.ClusterServiceClassSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.servicecatalog.api.model.ClusterServiceClassSpec,io.fabric8.servicecatalog.api.model.ClusterServiceClassSpecBuilder>{
  public ClusterServiceClassSpecBuilder() {
    this(false);
  }
  public ClusterServiceClassSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new ClusterServiceClassSpec(), validationEnabled);
  }
  public ClusterServiceClassSpecBuilder(io.fabric8.servicecatalog.api.model.ClusterServiceClassSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterServiceClassSpecBuilder(io.fabric8.servicecatalog.api.model.ClusterServiceClassSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ClusterServiceClassSpec(), validationEnabled);
  }
  public ClusterServiceClassSpecBuilder(io.fabric8.servicecatalog.api.model.ClusterServiceClassSpecFluent<?> fluent,io.fabric8.servicecatalog.api.model.ClusterServiceClassSpec instance) {
    this(fluent, instance, false);
  }
  public ClusterServiceClassSpecBuilder(io.fabric8.servicecatalog.api.model.ClusterServiceClassSpecFluent<?> fluent,io.fabric8.servicecatalog.api.model.ClusterServiceClassSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withBindable(instance.getBindable()); 
    fluent.withBindingRetrievable(instance.getBindingRetrievable()); 
    fluent.withClusterServiceBrokerName(instance.getClusterServiceBrokerName()); 
    fluent.withDefaultProvisionParameters(instance.getDefaultProvisionParameters()); 
    fluent.withDescription(instance.getDescription()); 
    fluent.withExternalID(instance.getExternalID()); 
    fluent.withExternalMetadata(instance.getExternalMetadata()); 
    fluent.withExternalName(instance.getExternalName()); 
    fluent.withPlanUpdatable(instance.getPlanUpdatable()); 
    fluent.withRequires(instance.getRequires()); 
    fluent.withTags(instance.getTags()); 
    this.validationEnabled = validationEnabled; 
  }
  public ClusterServiceClassSpecBuilder(io.fabric8.servicecatalog.api.model.ClusterServiceClassSpec instance) {
    this(instance,false);
  }
  public ClusterServiceClassSpecBuilder(io.fabric8.servicecatalog.api.model.ClusterServiceClassSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withBindable(instance.getBindable()); 
    this.withBindingRetrievable(instance.getBindingRetrievable()); 
    this.withClusterServiceBrokerName(instance.getClusterServiceBrokerName()); 
    this.withDefaultProvisionParameters(instance.getDefaultProvisionParameters()); 
    this.withDescription(instance.getDescription()); 
    this.withExternalID(instance.getExternalID()); 
    this.withExternalMetadata(instance.getExternalMetadata()); 
    this.withExternalName(instance.getExternalName()); 
    this.withPlanUpdatable(instance.getPlanUpdatable()); 
    this.withRequires(instance.getRequires()); 
    this.withTags(instance.getTags()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.servicecatalog.api.model.ClusterServiceClassSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.servicecatalog.api.model.ClusterServiceClassSpec build() {
    ClusterServiceClassSpec buildable = new ClusterServiceClassSpec(fluent.getBindable(),fluent.getBindingRetrievable(),fluent.getClusterServiceBrokerName(),fluent.getDefaultProvisionParameters(),fluent.getDescription(),fluent.getExternalID(),fluent.getExternalMetadata(),fluent.getExternalName(),fluent.getPlanUpdatable(),fluent.getRequires(),fluent.getTags());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterServiceClassSpecBuilder that = (ClusterServiceClassSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> servicecatalog-model-6.3.1-sources.jar: io/fabric8/servicecatalog/api/model/ClusterServiceClassSpecBuilder.java <==
package io.fabric8.servicecatalog.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ClusterServiceClassSpecBuilder extends ClusterServiceClassSpecFluentImpl<ClusterServiceClassSpecBuilder> implements VisitableBuilder<ClusterServiceClassSpec,ClusterServiceClassSpecBuilder>{
  public ClusterServiceClassSpecBuilder() {
    this(false);
  }
  public ClusterServiceClassSpecBuilder(Boolean validationEnabled) {
    this(new ClusterServiceClassSpec(), validationEnabled);
  }
  public ClusterServiceClassSpecBuilder(ClusterServiceClassSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterServiceClassSpecBuilder(ClusterServiceClassSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ClusterServiceClassSpec(), validationEnabled);
  }
  public ClusterServiceClassSpecBuilder(ClusterServiceClassSpecFluent<?> fluent,ClusterServiceClassSpec instance) {
    this(fluent, instance, false);
  }
  public ClusterServiceClassSpecBuilder(ClusterServiceClassSpecFluent<?> fluent,ClusterServiceClassSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withBindable(instance.getBindable()); 
    fluent.withBindingRetrievable(instance.getBindingRetrievable()); 
    fluent.withClusterServiceBrokerName(instance.getClusterServiceBrokerName()); 
    fluent.withDefaultProvisionParameters(instance.getDefaultProvisionParameters()); 
    fluent.withDescription(instance.getDescription()); 
    fluent.withExternalID(instance.getExternalID()); 
    fluent.withExternalMetadata(instance.getExternalMetadata()); 
    fluent.withExternalName(instance.getExternalName()); 
    fluent.withPlanUpdatable(instance.getPlanUpdatable()); 
    fluent.withRequires(instance.getRequires()); 
    fluent.withTags(instance.getTags()); 
    this.validationEnabled = validationEnabled; 
  }
  public ClusterServiceClassSpecBuilder(ClusterServiceClassSpec instance) {
    this(instance,false);
  }
  public ClusterServiceClassSpecBuilder(ClusterServiceClassSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withBindable(instance.getBindable()); 
    this.withBindingRetrievable(instance.getBindingRetrievable()); 
    this.withClusterServiceBrokerName(instance.getClusterServiceBrokerName()); 
    this.withDefaultProvisionParameters(instance.getDefaultProvisionParameters()); 
    this.withDescription(instance.getDescription()); 
    this.withExternalID(instance.getExternalID()); 
    this.withExternalMetadata(instance.getExternalMetadata()); 
    this.withExternalName(instance.getExternalName()); 
    this.withPlanUpdatable(instance.getPlanUpdatable()); 
    this.withRequires(instance.getRequires()); 
    this.withTags(instance.getTags()); 
    this.validationEnabled = validationEnabled; 
  }
  ClusterServiceClassSpecFluent<?> fluent;
  Boolean validationEnabled;
  public ClusterServiceClassSpec build() {
    ClusterServiceClassSpec buildable = new ClusterServiceClassSpec(fluent.getBindable(),fluent.getBindingRetrievable(),fluent.getClusterServiceBrokerName(),fluent.getDefaultProvisionParameters(),fluent.getDescription(),fluent.getExternalID(),fluent.getExternalMetadata(),fluent.getExternalName(),fluent.getPlanUpdatable(),fluent.getRequires(),fluent.getTags());
    return buildable;
  }
  
}
